@@ -16,14 +16,13 @@
 
 package com.google.gson;
 
-import com.google.gson.internal.$Gson$Preconditions;
+import com.google.gson.internal.LazilyParsedNumber;
 import java.math.BigDecimal;
 import java.math.BigInteger;
-
-import com.google.gson.internal.LazilyParsedNumber;
+import java.util.Objects;
 
 /**
- * A class representing a Json primitive value. A primitive value
+ * A class representing a JSON primitive value. A primitive value
  * is either a String, a Java primitive, or a Java primitive
  * wrapper type.
  *
@@ -39,8 +38,9 @@ public final class JsonPrimitive extends JsonElement {
    *
    * @param bool the value to create the primitive with.
    */
+  @SuppressWarnings("deprecation") // superclass constructor
   public JsonPrimitive(Boolean bool) {
-    value = $Gson$Preconditions.checkNotNull(bool);
+    value = Objects.requireNonNull(bool);
   }
 
   /**
@@ -48,8 +48,9 @@ public final class JsonPrimitive extends JsonElement {
    *
    * @param number the value to create the primitive with.
    */
+  @SuppressWarnings("deprecation") // superclass constructor
   public JsonPrimitive(Number number) {
-    value = $Gson$Preconditions.checkNotNull(number);
+    value = Objects.requireNonNull(number);
   }
 
   /**
@@ -57,24 +58,27 @@ public final class JsonPrimitive extends JsonElement {
    *
    * @param string the value to create the primitive with.
    */
+  @SuppressWarnings("deprecation") // superclass constructor
   public JsonPrimitive(String string) {
-    value = $Gson$Preconditions.checkNotNull(string);
+    value = Objects.requireNonNull(string);
   }
 
   /**
    * Create a primitive containing a character. The character is turned into a one character String
-   * since Json only supports String.
+   * since JSON only supports String.
    *
    * @param c the value to create the primitive with.
    */
+  @SuppressWarnings("deprecation") // superclass constructor
   public JsonPrimitive(Character c) {
     // convert characters to strings since in JSON, characters are represented as a single
     // character string
-    value = $Gson$Preconditions.checkNotNull(c).toString();
+    value = Objects.requireNonNull(c).toString();
   }
 
   /**
    * Returns the same value as primitives are immutable.
+   *
    * @since 2.8.2
    */
   @Override
@@ -92,9 +96,10 @@ public final class JsonPrimitive extends JsonElement {
   }
 
   /**
-   * convenience method to get this element as a boolean value.
-   *
-   * @return get this element as a primitive boolean value.
+   * Convenience method to get this element as a boolean value.
+   * If this primitive {@linkplain #isBoolean() is not a boolean}, the string value
+   * is parsed using {@link Boolean#parseBoolean(String)}. This means {@code "true"} (ignoring
+   * case) is considered {@code true} and any other value is considered {@code false}.
    */
   @Override
   public boolean getAsBoolean() {
@@ -115,14 +120,21 @@ public final class JsonPrimitive extends JsonElement {
   }
 
   /**
-   * convenience method to get this element as a Number.
+   * Convenience method to get this element as a {@link Number}.
+   * If this primitive {@linkplain #isString() is a string}, a lazily parsed {@code Number}
+   * is constructed which parses the string when any of its methods are called (which can
+   * lead to a {@link NumberFormatException}).
    *
-   * @return get this element as a Number.
-   * @throws NumberFormatException if the value contained is not a valid Number.
+   * @throws UnsupportedOperationException if this primitive is neither a number nor a string.
    */
   @Override
   public Number getAsNumber() {
-    return value instanceof String ? new LazilyParsedNumber((String) value) : (Number) value;
+    if (value instanceof Number) {
+      return (Number) value;
+    } else if (value instanceof String) {
+      return new LazilyParsedNumber((String) value);
+    }
+    throw new UnsupportedOperationException("Primitive is neither a number nor a string");
   }
 
   /**
@@ -134,27 +146,21 @@ public final class JsonPrimitive extends JsonElement {
     return value instanceof String;
   }
 
-  /**
-   * convenience method to get this element as a String.
-   *
-   * @return get this element as a String.
-   */
+  // Don't add Javadoc, inherit it from super implementation; no exceptions are thrown here
   @Override
   public String getAsString() {
-    if (isNumber()) {
+    if (value instanceof String) {
+      return (String) value;
+    } else if (isNumber()) {
       return getAsNumber().toString();
     } else if (isBoolean()) {
       return ((Boolean) value).toString();
-    } else {
-      return (String) value;
     }
+    throw new AssertionError("Unexpected value type: " + value.getClass());
   }
 
   /**
-   * convenience method to get this element as a primitive double.
-   *
-   * @return get this element as a primitive double.
-   * @throws NumberFormatException if the value contained is not a valid double.
+   * @throws NumberFormatException {@inheritDoc}
    */
   @Override
   public double getAsDouble() {
@@ -162,33 +168,24 @@ public final class JsonPrimitive extends JsonElement {
   }
 
   /**
-   * convenience method to get this element as a {@link BigDecimal}.
-   *
-   * @return get this element as a {@link BigDecimal}.
-   * @throws NumberFormatException if the value contained is not a valid {@link BigDecimal}.
+   * @throws NumberFormatException {@inheritDoc}
    */
   @Override
   public BigDecimal getAsBigDecimal() {
-    return value instanceof BigDecimal ? (BigDecimal) value : new BigDecimal(value.toString());
+    return value instanceof BigDecimal ? (BigDecimal) value : new BigDecimal(getAsString());
   }
 
   /**
-   * convenience method to get this element as a {@link BigInteger}.
-   *
-   * @return get this element as a {@link BigInteger}.
-   * @throws NumberFormatException if the value contained is not a valid {@link BigInteger}.
+   * @throws NumberFormatException {@inheritDoc}
    */
   @Override
   public BigInteger getAsBigInteger() {
     return value instanceof BigInteger ?
-        (BigInteger) value : new BigInteger(value.toString());
+        (BigInteger) value : new BigInteger(getAsString());
   }
 
   /**
-   * convenience method to get this element as a float.
-   *
-   * @return get this element as a float.
-   * @throws NumberFormatException if the value contained is not a valid float.
+   * @throws NumberFormatException {@inheritDoc}
    */
   @Override
   public float getAsFloat() {
@@ -196,10 +193,10 @@ public final class JsonPrimitive extends JsonElement {
   }
 
   /**
-   * convenience method to get this element as a primitive long.
+   * Convenience method to get this element as a primitive long.
    *
-   * @return get this element as a primitive long.
-   * @throws NumberFormatException if the value contained is not a valid long.
+   * @return this element as a primitive long.
+   * @throws NumberFormatException {@inheritDoc}
    */
   @Override
   public long getAsLong() {
@@ -207,10 +204,7 @@ public final class JsonPrimitive extends JsonElement {
   }
 
   /**
-   * convenience method to get this element as a primitive short.
-   *
-   * @return get this element as a primitive short.
-   * @throws NumberFormatException if the value contained is not a valid short value.
+   * @throws NumberFormatException {@inheritDoc}
    */
   @Override
   public short getAsShort() {
@@ -218,26 +212,41 @@ public final class JsonPrimitive extends JsonElement {
   }
 
  /**
-  * convenience method to get this element as a primitive integer.
-  *
-  * @return get this element as a primitive integer.
-  * @throws NumberFormatException if the value contained is not a valid integer.
+  * @throws NumberFormatException {@inheritDoc}
   */
   @Override
   public int getAsInt() {
     return isNumber() ? getAsNumber().intValue() : Integer.parseInt(getAsString());
   }
 
+  /**
+   * @throws NumberFormatException {@inheritDoc}
+   */
   @Override
   public byte getAsByte() {
     return isNumber() ? getAsNumber().byteValue() : Byte.parseByte(getAsString());
   }
 
+  /**
+   * @throws UnsupportedOperationException if the string value of this
+   * primitive is empty.
+   * @deprecated This method is misleading, as it does not get this element as a char but rather as
+   * a string's first character.
+   */
+  @Deprecated
   @Override
   public char getAsCharacter() {
-    return getAsString().charAt(0);
+    String s = getAsString();
+    if (s.isEmpty()) {
+      throw new UnsupportedOperationException("String value is empty");
+    } else {
+      return s.charAt(0);
+    }
   }
 
+  /**
+   * Returns the hash code of this object.
+   */
   @Override
   public int hashCode() {
     if (value == null) {
@@ -255,6 +264,11 @@ public final class JsonPrimitive extends JsonElement {
     return value.hashCode();
   }
 
+  /**
+   * Returns whether the other object is equal to this. This method only considers
+   * the other object to be equal if it is an instance of {@code JsonPrimitive} and
+   * has an equal value.
+   */
   @Override
   public boolean equals(Object obj) {
     if (this == obj) {
