@@ -16,6 +16,8 @@
 
 package com.google.gson.internal;
 
+import java.util.Objects;
+
 /**
  * A simple utility class used to check method Preconditions.
  *
@@ -34,6 +36,12 @@ public final class $Gson$Preconditions {
     throw new UnsupportedOperationException();
   }
 
+  /**
+   * @deprecated
+   * This is an internal Gson method. Use {@link Objects#requireNonNull(Object)} instead.
+   */
+  // Only deprecated for now because external projects might be using this by accident
+  @Deprecated
   public static <T> T checkNotNull(T obj) {
     if (obj == null) {
       throw new NullPointerException();
