@@ -8,5 +8,9 @@ module com.google.gson {
 	exports com.google.gson.reflect;
 	exports com.google.gson.stream;
 
-	requires transitive java.sql;
+	// Optional dependency on java.sql
+	requires static java.sql;
+
+	// Optional dependency on jdk.unsupported for JDK's sun.misc.Unsafe
+	requires static jdk.unsupported;
 }
